@@ -48,7 +48,7 @@ class Task:
                 spinner.next()
         if self.task_state == FAILURE:
             self.update(include_result=True)
-            raise Exception("ERROR:" + str(self.task_result))
+            raise Exception("ERROR for task {}:{}".format(self.task_id, self.task_result))
         if self.task_state == STOPPED:
             print("Task has been stopped.")
         if show_progress:
