@@ -3,7 +3,7 @@ import hashlib
 import bson
 import requests
 
-from .common import getToken, read_in_chunks
+from .common import getToken, read_in_chunks, MID_VERBOSITY, getVerbosity
 from .Task import Task
 from .saving.saving import determine_model, hash_model
 from .web.urls import RETRIEVE_MODEL_URL, HASH_URL, COMPILE_URL
@@ -28,13 +28,15 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
               "collection": 2, "modelType": library}
     response = requests.get(HASH_URL, params=params)
     if response.status_code == 200:
-        print("Model already on server. Returning result...")
+        if getVerbosity() >= MID_VERBOSITY:
+            print("Model already on server. Returning result...")
         return response.json()
     elif response.status_code != 204:
         raise ConnectionAbortedError("Checking hash not worked. {0}".format(response.content))
     else:
-        print("Model not found on server.")
-        print("Saving model locally...")
+        if getVerbosity() >= MID_VERBOSITY:
+            print("Model not found on server.")
+            print("Saving model locally...")
         file_path = save_model(model, library)
         with open(file_path, "rb") as file:
             size = 0
@@ -43,7 +45,8 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
             if model_label == "":
                 model_label = file_path
             params["given_name"] = model_label
-            print("Model saved locally.")
+            if getVerbosity() >= MID_VERBOSITY:
+                print("Model saved locally.")
             print("Model file size is {} bytes. Uploading model now...".format(size))
             task = Task(compileApi(file, params))
             if not asynchronous:
@@ -56,5 +59,7 @@ def compileApi(file, params):
     file.seek(0)
     files = {'file': file}
     response = requests.post(COMPILE_URL, files=files, params=params)
+    if response.status_code != 200:
+        raise ValueError(response.text)
     return response.json()
 
